@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2020-2022 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+** Copyright (C) 2020-2024 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 **
 ** This program is free software; you can redistribute it and/or modify it
 ** under the terms of the GNU General Public License as published by the
@@ -17,6 +17,9 @@
 **
 */
 
+#include "config.h"
+#include "mu-logger.hh"
+
 #define G_LOG_USE_STRUCTURED
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -31,8 +34,6 @@
 #include <thread>
 #include <mutex>
 
-#include "mu-logger.hh"
-
 using namespace Mu;
 
 static bool			MuLogInitialized = false;
@@ -51,15 +52,13 @@ maybe_open_logfile()
 
 	const auto logdir{to_string_gchar(g_path_get_dirname(MuLogPath.c_str()))};
 	if (g_mkdir_with_parents(logdir.c_str(), 0700) != 0) {
-		std::cerr << "creating " << logdir << " failed:" << g_strerror(errno)
-			  << std::endl;
+		mu_printerrln("creating {} failed: {}", logdir, g_strerror(errno));
 		return false;
 	}
 
 	MuStream.open(MuLogPath, std::ios::out | std::ios::app);
 	if (!MuStream.is_open()) {
-		std::cerr << "opening " << MuLogPath << " failed:" << g_strerror(errno)
-			  << std::endl;
+		mu_printerrln("opening {} failed: {}", MuLogPath, g_strerror(errno));
 		return false;
 	}
 
@@ -86,8 +85,7 @@ maybe_rotate_logfile()
 		MuStream.close();
 
 	if (g_rename(MuLogPath.c_str(), old.c_str()) != 0)
-		std::cerr << "failed to rename " << MuLogPath << " -> " << old.c_str() << ": "
-			  << g_strerror(errno) << std::endl;
+		mu_printerrln("failed to rename {} -> {}: {}", MuLogPath, old, g_strerror(errno));
 
 	return maybe_open_logfile();
 }
@@ -121,10 +119,29 @@ log_stdouterr(GLogLevelFlags level, const GLogField* fields, gsize n_fields, gpo
 	return g_log_writer_standard_streams(level, fields, n_fields, user_data);
 }
 
+
+
+// log to some logging system; the one that is available & works of journal,
+// syslog, file.
 static GLogWriterOutput
-log_journal(GLogLevelFlags level, const GLogField* fields, gsize n_fields, gpointer user_data)
+log_system(GLogLevelFlags level, const GLogField* fields, gsize n_fields, gpointer user_data)
 {
-	return g_log_writer_journald(level, fields, n_fields, user_data);
+	GLogWriterOutput res = G_LOG_WRITER_UNHANDLED;
+
+#ifdef MAYBE_USE_JOURNAL
+	res = g_log_writer_journald(level, fields, n_fields, user_data);
+	if (res == G_LOG_WRITER_HANDLED)
+		return res;
+#endif /*MAYBE_USE_JOURNAL*/
+
+#ifdef MAYBE_USE_SYSLOG
+	/* since glib 2.80 */
+	res = g_log_writer_syslog(level, fields, n_fields, user_data);
+	if (res == G_LOG_WRITER_HANDLED)
+		return res;
+#endif /*MAYBE_USE_SYSLOG*/
+
+	return res = log_file(level, fields, n_fields, user_data);
 }
 
 
@@ -159,18 +176,18 @@ Mu::Logger::Logger(const std::string& path, Mu::Logger::Options opts)
 		    }
 
 		    // log to the journal, or, if not available to a file.
-		    if (any_of(MuLogOptions & Options::File) ||
-			log_journal(level, fields, n_fields, user_data) != G_LOG_WRITER_HANDLED)
-			    return log_file(level, fields, n_fields, user_data);
-		    else
-			    return G_LOG_WRITER_HANDLED;
+		    if (any_of(MuLogOptions & Options::File))
+			return log_file(level, fields, n_fields, user_data);
+
+		    return log_system(level, fields, n_fields, user_data);
 	    },
 	    NULL,
 	    NULL);
 
-	g_message("logging initialized; debug: %s, stdout/stderr: %s",
-		  any_of(opts & Options::Debug) ? "yes" : "no",
-		  any_of(opts & Options::StdOutErr) ? "yes" : "no");
+	if (none_of(opts & Options::Quiet))
+		g_message("logging initialized; debug: %s, stdout/stderr: %s",
+			  any_of(opts & Options::Debug) ? "yes" : "no",
+			  any_of(opts & Options::StdOutErr) ? "yes" : "no");
 
 	MuLogInitialized = true;
 }
@@ -192,14 +209,16 @@ Logger::~Logger()
 #include <atomic>
 
 #include "mu-test-utils.hh"
+#include "mu-utils-file.hh"
 
 static void
 test_logger_threads(void)
 {
-	const auto testpath{test_random_tmpdir() + "/test.log"};
-	g_message("log-file: %s", testpath.c_str());
+	TempDir temp_dir;
+	const auto testpath{join_paths(temp_dir.path(), "test.log")};
+	mu_message("log-file: {}", testpath);
 
-	auto logger = Logger::make(testpath.c_str(), Logger::Options::File | Logger::Options::Debug);
+	auto logger = Logger::make(testpath, Logger::Options::File | Logger::Options::Debug);
 	assert_valid_result(logger);
 
 	const auto		thread_num = 16;
@@ -210,9 +229,9 @@ test_logger_threads(void)
 	/* log to the logger file from many threass */
 	for (auto n = 0; n != thread_num; ++n)
 		threads.emplace_back(
-			std::thread([n,&running]{
+			std::thread([&running]{
 				while (running) {
-					g_debug("log message from thread <%d>", n);
+					//mu_debug("log message from thread <{}>", n);
 					std::this_thread::yield();
 				}
 			}));
