@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2017-2022 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+** Copyright (C) 2017-2025 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 **
 **  This library is free software; you can redistribute it and/or
 **  modify it under the terms of the GNU Lesser General Public License
@@ -21,21 +21,20 @@
 #include <glib.h>
 
 #include <iostream>
-#include <sstream>
 #include <functional>
 #include <array>
 
 #include "mu-utils.hh"
+#include "mu-utils-file.hh"
+
 #include "mu-test-utils.hh"
-#include "mu-error.hh"
 
 using namespace Mu;
 
-
 struct Case {
-	const std::string expr;
-	bool              is_first{};
-	const std::string expected;
+	std::string expr;
+	bool        is_first{};
+	std::string expected;
 };
 using CaseVec  = std::vector<Case>;
 using ProcFunc = std::function<std::string(std::string, bool)>;
@@ -45,14 +44,8 @@ test_cases(const CaseVec& cases, ProcFunc proc)
 {
 	for (const auto& casus : cases) {
 		const auto res = proc(casus.expr, casus.is_first);
-		if (g_test_verbose()) {
-			std::cout << "\n";
-			std::cout << casus.expr << ' ' << casus.is_first << std::endl;
-			std::cout << "exp: '" << casus.expected << "'" << std::endl;
-			std::cout << "got: '" << res << "'" << std::endl;
-		}
-
-		g_assert_true(casus.expected == res);
+		//mu_println("'{}'\n'{}'", casus.expected, res);
+		assert_equal(casus.expected, res);
 	}
 }
 
@@ -68,9 +61,10 @@ test_date_basic()
 	}
 
 	g_setenv("TZ", hki, TRUE);
-	constexpr std::array<std::tuple<const char*, bool/*is_first*/, int64_t>, 13> cases = {{
+	const std::vector<std::tuple<const char*, bool/*is_first*/, ::time_t>> cases = {{
 			{"2015-09-18T09:10:23", true, 1442556623},
 			{"1972-12-14T09:10:23", true, 93165023},
+			{"1972-12-14T09:10", true,    93165000},
 			{"1854-11-18T17:10:23", true, 0},
 
 			{"2000-02-31T09:10:23", true, 951861599},
@@ -87,13 +81,13 @@ test_date_basic()
 
 			// {"fnorb", true,  -1},
 			// {"fnorb", false, -1},
-			{"", false, G_MAXINT64},
-			{"", true, 0}
+			{"", false, time_t_max},
+			{"", true, time_t_min}
 		}};
 
 	for (auto& test: cases) {
 		if (g_test_verbose())
-			g_debug("checking %s", std::get<0>(test));
+			mu_debug("checking {}", std::get<0>(test));
 		g_assert_cmpuint(parse_date_time(std::get<0>(test),
 						 std::get<1>(test)).value_or(-1),==,
 				 std::get<2>(test));
@@ -101,7 +95,7 @@ test_date_basic()
 }
 
 static void
-test_date_ymwdhMs(void)
+test_date_ymwdhMs()
 {
 	struct testcase {
 		std::string	expr;
@@ -109,7 +103,8 @@ test_date_ymwdhMs(void)
 		int		tolerance;
 	};
 
-	std::array<testcase, 7> cases = {{
+
+	const std::array<testcase, 7> cases = {{
 		{"7s", 7, 1},
 		{"3M", 3 * 60, 1},
 		{"3h", 3 * 60 * 60, 1},
@@ -154,13 +149,32 @@ test_parse_size()
 	g_assert_false(!!parse_size("scoobydoobydoo", false));
 }
 
+static void
+test_utf8_clean()
+{
+	assert_equal(utf8_clean("James Holden"), "James Holden");
+
+	const std::array<char, 3> invalid_bytes ={ 'a' , static_cast<char>(0xff), 'c'};
+	std::string invalid{invalid_bytes.data(), invalid_bytes.size()};
+
+	g_assert_false(g_utf8_validate(invalid.c_str(), invalid.length(), nullptr));
+
+	const auto valid = utf8_clean(std::move(invalid));
+	g_assert_true(g_utf8_validate(valid.c_str(), valid.length(), {}));
+	assert_equal(valid, "a\357\277\275c"); // replacement char
+}
+
 static void
 test_flatten()
 {
 	CaseVec cases = {
-	    {"Менделе́ев", true, "менделеев"},
-	    {"", false, ""},
-	    {"Ångström", true, "angstrom"},
+	    {"Менделе́ев",	true, "менделеев"},
+	    {"",		true, ""},
+	    {"Ångström",	true, "angstrom"},
+	    {"đodø",		true, "dodo"},
+
+	    // don't touch combining characters in CJK etc.
+	    {"スポンサーシップ募集", true, "スポンサーシップ募集"}
 	};
 
 	test_cases(cases, [](auto s, auto f) { return utf8_flatten(s); });
@@ -184,19 +198,33 @@ static void
 test_clean()
 {
 	CaseVec cases = {
-	    {"\t a\t\nb ", true, "a  b"},
-	    {"", false, ""},
-	    {"Ångström", true, "Ångström"},
+	    {"\t a\t\nb ",	true, "a  b"},
+	    {"",		true, ""},
+	    {"Ångström",	true, "Ångström"},
+	    {"\345\245",	true, ".."},
 	};
 
 	test_cases(cases, [](auto s, auto f) { return utf8_clean(s); });
 }
 
+static void
+test_word_break()
+{
+	CaseVec cases = {
+	    {"aap+noot&mies",            true, "aap noot mies"},
+	    {"hallo",                    true, "hallo"},
+	    {"  foo-bar###cuux,fnorb  ", true, "foo bar cuux fnorb"},
+	    {"eyes\nof\tMedusa",         true, "eyes of Medusa"},
+	};
+
+	test_cases(cases, [](auto s, auto f) { return utf8_wordbreak(s); });
+}
+
 static void
 test_format()
 {
-	g_assert_true(format("hello %s", "world") == "hello world");
-	g_assert_true(format("hello %s, %u", "world", 123) == "hello world, 123");
+	g_assert_true(mu_format("hello {}", "world") == "hello world");
+	g_assert_true(mu_format("hello {}, {}", "world", 123) == "hello world, 123");
 }
 
 static void
@@ -282,38 +310,8 @@ test_locale_workaround()
 	g_assert_true(locale_workaround());
 }
 
-enum struct TestEnum { A, B, C };
-constexpr AssocPairs<TestEnum, std::string_view, 3>
-test_epairs = {{
-	{TestEnum::A, "a"},
-	{TestEnum::B, "b"},
-	{TestEnum::C, "c"},
-}};
-
-static constexpr Option<std::string_view>
-to_name(TestEnum te)
-{
-	return to_second(test_epairs, te);
-}
-
-static constexpr Option<TestEnum>
-to_type(std::string_view name)
-{
-	return to_first(test_epairs, name);
-
-}
-
 static void
-test_enum_pairs(void)
-{
-	assert_equal(to_name(TestEnum::A).value(), "a");
-	g_assert_true(to_type("c").value() ==  TestEnum::C);
-}
-
-
-
-static void
-test_summarize(void)
+test_summarize()
 {
 	const char *txt =
 		"Khiron was fortified and made the seat of a pargana during "
@@ -333,8 +331,6 @@ test_summarize(void)
 			"fortification by the Bais raja Sathna. ");
 }
 
-
-
 int
 main(int argc, char* argv[])
 {
@@ -343,9 +339,11 @@ main(int argc, char* argv[])
 	g_test_add_func("/utils/date-basic", test_date_basic);
 	g_test_add_func("/utils/date-ymwdhMs", test_date_ymwdhMs);
 	g_test_add_func("/utils/parse-size", test_parse_size);
+	g_test_add_func("/utils/utf8-clean", test_utf8_clean);
 	g_test_add_func("/utils/flatten", test_flatten);
 	g_test_add_func("/utils/remove-ctrl", test_remove_ctrl);
 	g_test_add_func("/utils/clean", test_clean);
+	g_test_add_func("/utils/word-break", test_word_break);
 	g_test_add_func("/utils/format", test_format);
 	g_test_add_func("/utils/summarize", test_summarize);
 	g_test_add_func("/utils/split", test_split);
@@ -353,7 +351,6 @@ main(int argc, char* argv[])
 	g_test_add_func("/utils/define-bitmap", test_define_bitmap);
 	g_test_add_func("/utils/to-from-lexnum", test_to_from_lexnum);
 	g_test_add_func("/utils/locale-workaround", test_locale_workaround);
-	g_test_add_func("/utils/enum-pairs", test_enum_pairs);
 
 	return g_test_run();
 }
