@@ -180,7 +180,7 @@ When it is showing, respectively, From: or To:. It is a cons cell
 
 ;; marks for headers of the form; each is a cons-cell (basic . fancy)
 ;; each of which is basic ascii char and something fancy, respectively
-;; by default, we some conservative marks, even when 'fancy'
+;; by default, we use some conservative marks, even when 'fancy'
 ;; so they're less likely to break if people don't have certain fonts.
 ;; However, if you want to be really 'fancy', you could use something like
 ;; the following; esp. with a newer Emacs with color-icon support.
@@ -268,7 +268,7 @@ The first character of NAME is used as the shortcut."
      (lambda () (mu4e-get-time-date "Match messages after: ")))
     ("Bigger than"
      (lambda (msg bytes) (> (mu4e-msg-field msg :size) (* 1024 bytes)))
-     (lambda () (read-number "Match messages bigger than (Kbytes): "))))
+     (lambda () (read-number "Match messages bigger than (KB): "))))
   "List of custom markers-functions.
 
 The functions are to mark message that match some custom
@@ -281,7 +281,11 @@ and (optionally) PARAM, and should return non-nil when there's a
 match.
 * PARAM-FUNC is function that is evaluated once, and its value is
 then passed to PREDICATE-FUNC as PARAM. This is useful for
-getting user-input.")
+getting user-input.
+
+The default functions that take dates, use `mu4e-get-time-date'
+which wraps `parse-time-string' and hence requires the format to
+be compatible with that.")
 ;;; Internal variables/constants
 
 ;; docid cookies
@@ -788,8 +792,6 @@ present, don't do anything."
                              buf nil t))
       (kill-buffer buf))))
 
-
-
 ;;; Performing queries (internal)
 (defconst mu4e~search-message "Searching...")
 (defconst mu4e~no-matches     "No matching messages found")
@@ -885,11 +887,12 @@ COUNT is the number of messages found."
         (mu4e~headers-highlight (mu4e~headers-docid-at-point)))
       ;; maybe enable thread folding
       (when mu4e-search-threads
-        (mu4e-thread-mode))))
+        (mu4e-thread-mode)))
+    ;; might need updating
+    (setq header-line-format (mu4e~header-line-format)))
   ;; run-hooks
   (run-hooks 'mu4e-headers-found-hook))
 
-
 ;;; Marking
 
 (defmacro mu4e~headers-defun-mark-for (mark)
@@ -1179,8 +1182,7 @@ The following specs are supported:
   (setq
    truncate-lines t
    buffer-undo-list t ;; don't record undo information
-   overwrite-mode nil
-   header-line-format (mu4e~header-line-format))
+   overwrite-mode nil)
 
   (mu4e--mark-initialize) ;; initialize the marking subsystem
   (mu4e-context-minor-mode)
